import os
import lxml.etree as ET
import jinja2
import re


class ObjectToXml():

    def make_xml(self, save):
        for x in self.br_input:
            templateLoader = jinja2.FileSystemLoader(searchpath="./")
            templateEnv = jinja2.Environment(loader=templateLoader)
            template_file = self.template_path
            template = templateEnv.get_template(template_file)
            # templateLoader = jinja2.PackageLoader(
            #     "acdh_baserow_utils", "templates"
            # )
            # templateEnv = jinja2.Environment(loader=templateLoader, trim_blocks=True, lstrip_blocks=True)
            # template = templateEnv.get_template('./tei.xml')
            xml = template.render({"objects": [x]})
            xml = re.sub(r'\s+$', '', xml, flags=re.MULTILINE)
            xml = ET.fromstring(xml)
            if save:
                filename = f"{x[self.filename]}.xml"
                os.makedirs(self.save_dir, exist_ok=True)
                with open(os.path.join(self.save_dir, filename), 'wb') as f:
                    f.write(ET.tostring(xml, pretty_print=True, encoding="utf-8"))
            yield ET.tostring(xml, pretty_print=True, encoding="utf-8")

    def __init__(
        self,
        br_input=None,
        save_dir=None,
        filename=None,
        template_path=None
    ):
        if br_input is None:
            print("please provide baserow input by using BaseRowClient().yield_rows() generator.")
        else:
            self.br_input = br_input
        if save_dir is None:
            self.save_dir = "out"
        else:
            self.save_dir = save_dir
        if template_path is None:
            self.template_path = "templates/tei.xml"
        else:
            self.template_path = template_path
        if filename is None:
            self.filename = "filename"
        else:
            self.filename = filename



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()


requirements = [
    'lxml',
    'jinja2'
]

setup_requirements = []

test_requirements = []

setup(
    author="Daniel Stoxreiter",
    author_email='daniel.stoxreiter@oeaw.ac.at',
    python_requires='>=3.8',
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
    ],
    description="Utility functions to serialize xml from object",
    install_requires=requirements,
    license="MIT license",
    long_description=readme,
    long_description_content_type='text/markdown',
    include_package_data=True,
    name='acdh_obj2xml_pyutils',
    packages=find_packages(include=['acdh_obj2xml_pyutils', 'acdh_obj2xml_pyutils.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/acdh-oeaw/acdh-obj2xml-pyutils',
    version='0.0.1',
    zip_safe=False,
)
